@@ -22,40 +22,45 @@ try:
 
         def _nonkeops_covar_func(self, x1, x2, diag=False):
             return self.covar_dist(
-                x1, x2, square_dist=True, diag=diag, dist_postprocess_func=postprocess_rbf, postprocess=True
+                x1,
+                x2,
+                square_dist=True,
+                diag=diag,
+                dist_postprocess_func=postprocess_rbf,
+                postprocess=True,
             )
 
         def covar_func(self, x1, x2, diag=False):
             # We only should use KeOps on big kernel matrices
             # If we would otherwise be performing Cholesky inference, (or when just computing a kernel matrix diag)
             # then don't apply KeOps
-            if (
-                diag
-                or x1.size(-2) < settings.max_cholesky_size.value()
-                or x2.size(-2) < settings.max_cholesky_size.value()
-            ):
-                return self._nonkeops_covar_func(x1, x2, diag=diag)
-            # TODO: x1 / x2 size checks are a work around for a very minor bug in KeOps.
-            # This bug is fixed on KeOps master, and we'll remove that part of the check
-            # when they cut a new release.
-            elif x1.size(-2) == 1 or x2.size(-2) == 1:
-                return self._nonkeops_covar_func(x1, x2, diag=diag)
-            else:
-                with torch.autograd.enable_grad():
-                    x1_ = KEOLazyTensor(x1[..., :, None, :])
-                    x2_ = KEOLazyTensor(x2[..., None, :, :])
+            # enable gradients to ensure that test time caches on small predictions are still
+            # backprop-able
+            with torch.autograd.enable_grad():
+                if (
+                    diag
+                    or x1.size(-2) < settings.max_cholesky_size.value()
+                    or x2.size(-2) < settings.max_cholesky_size.value()
+                ):
+                    return self._nonkeops_covar_func(x1, x2, diag=diag)
 
-                    K = (-((x1_ - x2_) ** 2).sum(-1) / 2).exp()
+                x1_ = KEOLazyTensor(x1[..., :, None, :])
+                x2_ = KEOLazyTensor(x2[..., None, :, :])
 
-                    return K
+                K = (-((x1_ - x2_) ** 2).sum(-1) / 2).exp()
+
+                return K
 
         def forward(self, x1, x2, diag=False, **params):
             x1_ = x1.div(self.lengthscale)
             x2_ = x2.div(self.lengthscale)
 
-            covar_func = lambda x1, x2, diag=False: self.covar_func(x1, x2, diag)
-            return KeOpsLazyTensor(x1_, x2_, covar_func)
+            covar_func = lambda x1, x2, diag=diag: self.covar_func(x1, x2, diag)
 
+            if diag:
+                return covar_func(x1_, x2_, diag=True)
+
+            return KeOpsLazyTensor(x1_, x2_, covar_func)
 
 except ImportError:
 
