@@ -3,7 +3,7 @@
 import torch
 
 from .. import settings
-from ..utils.broadcasting import _matmul_broadcast_shape, _mul_broadcast_shape
+from ..utils.broadcasting import _matmul_broadcast_shape, _mul_broadcast_shape, _to_helper
 from ..utils.deprecation import bool_compat
 from ..utils.getitem import _noop_index
 from .lazy_tensor import LazyTensor, delazify
@@ -35,14 +35,14 @@ class CatLazyTensor(LazyTensor):
     dimension.
 
     Args:
-        - :attr:`lazy_tensors` (list of LazyTensors):
+        lazy_tensors (list of LazyTensors):
             A list of LazyTensors whose sizes are the same except in
-            concatenating dimension :attr:`dim`
-        - :attr:`dim` (int):
+            concatenating dimension dim
+        dim (int):
             The concatenating dimension which can be a batch dimension.
-        - :attr:`output_device` (torch.device):
-            The CatLazyTensor will appear to appear on :attr:`output_device`
-            and place any output `torch.Tensors` on :attr:`output_device`
+        output_device (torch.device):
+            The CatLazyTensor will appear to appear on output_device
+            and place any output `torch.Tensors` on output_device
     """
 
     def _check_args(self, *lazy_tensors, dim=0, output_device=None):
@@ -181,7 +181,10 @@ class CatLazyTensor(LazyTensor):
         if len(res_list) == 1:
             return res_list[0].view(target_shape).to(self.device)
         else:
-            return torch.cat(res_list).view(target_shape).to(self.device)
+            # Explicitly move tensors to one device as torch.cat no longer moves tensors:
+            # https://github.com/pytorch/pytorch/issues/35045
+            res_list = [lazy_tensor.to(self.device) for lazy_tensor in res_list]
+            return torch.cat(res_list).view(target_shape)
 
     def _getitem(self, row_index, col_index, *batch_indices):
         indices = [*batch_indices, row_index, col_index]
@@ -364,15 +367,22 @@ class CatLazyTensor(LazyTensor):
     def device_count(self):
         return len(set(self.devices))
 
-    def to(self, device_id):
+    def to(self, *args, **kwargs):
         """
-        returns a new CatLazyTensor with device_id as the output_device
+        Returns a new CatLazyTensor with device as the output_device and dtype
+        as the dtype.
         Warning: this does not move the LazyTensors in this CatLazyTensor to
-        device_id
+        device.
         """
-        new_kwargs = dict(self._kwargs)
-        new_kwargs["output_device"] = device_id
-        return self.__class__(*self._args, **new_kwargs)
+        device, dtype = _to_helper(*args, **kwargs)
+
+        new_kwargs = {**self._kwargs, "output_device": device}
+        res = self.__class__(*self._args, **new_kwargs)
+
+        if dtype is not None:
+            res = res.type(dtype)
+
+        return res
 
     def all_to(self, device_id):
         """
