@@ -5,6 +5,7 @@ from .contour_integral_quad import contour_integral_quad
 from .linear_cg import linear_cg
 from .memoize import cached
 from .minres import minres
+from .nearest_neighbors import NNUtil
 from .pinverse import stable_pinverse
 from .qr import stable_qr
 from .stochastic_lq import StochasticLQ
@@ -40,4 +41,5 @@ __all__ = [
     "stable_pinverse",
     "stable_qr",
     "warnings",
+    "NNUtil",
 ]
