@@ -42,11 +42,11 @@ class BatchDecoupledVariationalStrategy(VariationalStrategy):
     Additionally, you can use a different set of kernel hyperparameters for the mean and the variance function.
     We recommend using this feature only with the :obj:`~gpytorch.mlls.PredictiveLogLikelihood` objective function
     as proposed in "Parametric Gaussian Process Regressors" (`Jankowiak et al. (2020)`_).
-    Use the :attr:`mean_var_batch_dim` to indicate which batch dimension corresponds to the different mean/var
+    Use the mean_var_batch_dim to indicate which batch dimension corresponds to the different mean/var
     kernels.
 
     .. note::
-        We recommend using the "right-most" batch dimension (i.e. :attr:`mean_var_batch_dim=-1`) for the dimension
+        We recommend using the "right-most" batch dimension (i.e. ``mean_var_batch_dim=-1``) for the dimension
         that corresponds to the different mean/variance kernel parameters.
 
         Assuming you want `b1` many independent GPs, the :obj:`~gpytorch.variational._VariationalDistribution`
